#include "scene.h"

Scene::Scene()
{   
    this->setSceneRect(QRectF(-100, -100, 400, 400));

    leftSide = new QGraphicsPolygonItem;
    topSide = new QGraphicsPolygonItem;
    rightSide = new QGraphicsPolygonItem;
    bottomSide = new QGraphicsPolygonItem;

    initPoints();
    createLeftSide();
    createTopSide();
    createRightSide();
    createBottomSide();

    leftSide->setBrush(QBrush(Qt::black));
    topSide->setBrush(QBrush(Qt::gray));
    rightSide->setBrush(QBrush(Qt::blue));
    bottomSide->setBrush(QBrush(Qt::green));

    this->addItem(leftSide);
    this->addItem(topSide);
    this->addItem(rightSide);
    this->addItem(bottomSide);

}

void Scene::initPoints()
{
    top_left_1=QPointF(0,0);
    top_left_2=QPointF(20,20);
    top_right_1=QPointF(200,0);
    top_right_2=QPointF(180,20);
    bottom_right_1=QPointF(200,200);
    bottom_right_2=QPointF(180,180);
    bottom_left_1=QPointF(0,200);
    bottom_left_2=QPointF(20,180);
}


void Scene::createLeftSide()
{
    QPolygonF left_polygon;
    left_polygon<<top_left_1
                <<top_left_2
                <<bottom_left_2
                <<bottom_left_1;
    leftSide->setPolygon(left_polygon);
}

void Scene::createTopSide()
{
    QPolygonF top_polygon;
    top_polygon<<top_left_1
               <<top_left_2
               <<top_right_2
               <<top_right_1;
    topSide->setPolygon(top_polygon);
}

void Scene::createRightSide()
{
    QPolygonF right_polygon;
    right_polygon<<top_right_1
                 <<top_right_2
                 <<bottom_right_2
                 <<bottom_right_1;
    rightSide->setPolygon(right_polygon);
}

void Scene::createBottomSide()
{
    QPolygonF bottom_polygon;
    bottom_polygon<<bottom_left_1
                <<bottom_left_2
                <<bottom_right_2
                <<bottom_right_1;
    bottomSide->setPolygon(bottom_polygon);
}




void Scene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
    itemUnderMouse = this->itemAt(mouseEvent->scenePos());
    lastMousePos = mouseEvent->scenePos();
}


void Scene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
{
    if ( itemUnderMouse == 0 ) return;

    QPointF offset = mouseEvent->scenePos()-lastMousePos; //
    QPointF p;

    if ( itemUnderMouse == leftSide ) {
        p = QPointF(offset.x(),0); //    
        top_left_1+=p;
        top_left_2+=p;
        bottom_left_2+=p;
        bottom_left_1+=p;
    }
    else if ( itemUnderMouse == topSide ) {
        p = QPointF(0,offset.y());
        top_left_1+=p;
        top_left_2+=p;
        top_right_1+=p;
        top_right_2+=p;
    }
    else if ( itemUnderMouse == rightSide ) {
        p = QPointF(offset.x(),0);
        top_right_1+=p;
        top_right_2+=p;
        bottom_right_2+=p;
        bottom_right_1+=p;
    }
    else if ( itemUnderMouse == bottomSide ) {
        p = QPointF(0,offset.y());
        bottom_left_1+=p;
        bottom_left_2+=p;
        bottom_right_1+=p;
        bottom_right_2+=p;
    }
    createLeftSide();
    createTopSide();
    createRightSide();
    createBottomSide();

    lastMousePos = mouseEvent->scenePos();
}
